@@ -8,6 +8,7 @@
 /* -------------------------------------------------- */
 
 #include "Model_TW.h"
+#include "models_tw.h"
 
 
 /* Model_TW Constructor */
@@ -66,7 +67,7 @@ double Model_TW::approx_dt(double* phi, double dt_scale) const {
       uu = unif_L() >= 0.5 ? 1.0 : -1.0;
 
       /* calculate accumulated evidence */
-      xx += dt_*vv + sqrtdt*DD*uu;
+      xx += dt_sims*vv + sqrtdt*DD*uu;
 
       /* check if accumulated evidence has crossed a decision threshold */
       if ((xx >= bu) || (xx <= bl)) {
@@ -1289,3 +1290,5 @@ int Model_TW::grid_pdf(double *Rrt, double *Rpdf_u, double *Rpdf_l, double *phi)
   return 0;
 
 }
+
+ModelTW_Callbacks CSTM_TW::callbacks;
